@@ -5,14 +5,18 @@ use warnings;
 
 use Carp ();
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 our $PREFIX  = '__cag_';
 
 require XSLoader;
 XSLoader::load('Class::Accessor::Inherited::XS', $VERSION);
 
 my $REGISTERED_TYPES = {};
-register_type(inherited => {no_cb => 1});
+register_types(
+    inherited => {installer => \&_mk_inherited_accessor},
+    class     => {installer => \&_mk_class_accessor},
+    varclass  => {installer => \&_mk_varclass_accessor},
+);
 
 sub import {
     my $pkg = shift;
@@ -53,6 +57,26 @@ sub mk_inherited_accessors {
     }
 }
 
+sub mk_class_accessors {
+    my $class = shift;
+
+    _mk_class_accessor($class, $_) for (@_);
+}
+
+sub mk_varclass_accessors {
+    my $class = shift;
+
+    _mk_varclass_accessor($class, $_) for (@_);
+}
+
+sub register_types {
+    my %args = @_;
+
+    while (my ($key, $val) = each %args) {
+        register_type($key, $val);
+    }
+}
+
 sub register_type {
     my ($type, $args) = @_;
 
@@ -60,10 +84,7 @@ sub register_type {
         Carp::confess("Type '$type' has already been registered");
     }
 
-    if (exists $args->{no_cb}) {
-        $args->{installer} = \&_mk_inherited_accessor;
-
-    } else {
+    if (!exists $args->{installer}) {
         $args->{installer} = sub {
             my ($class, $name, $field) = @_;
             install_inherited_cb_accessor("${class}::${name}", $field, $PREFIX.$field, $args->{read_cb}, $args->{write_cb});
@@ -83,18 +104,32 @@ sub _mk_inherited_accessor {
     install_inherited_accessor("${class}::${name}", $field, $PREFIX.$field);
 }
 
+sub _mk_class_accessor {
+    my ($class, $name) = @_;
+
+    install_class_accessor("${class}::${name}", 0);
+}
+
+sub _mk_varclass_accessor {
+    my ($class, $name) = @_;
+
+    install_class_accessor("${class}::${name}", 1);
+}
+
 1;
 __END__
 
 =head1 NAME
 
-Class::Accessor::Inherited::XS - Fast XS inherited accessors
+Class::Accessor::Inherited::XS - Fast XS inherited and class accessors
 
 =head1 SYNOPSIS
 
   #install accessors at compile time
   use Class::Accessor::Inherited::XS 
-      inherited => [qw/foo bar/], # here key names are equal to accessor names
+      inherited => [qw/foo bar/], # inherited accessors with key names equal to accessor names
+      class     => [qw/baz/],     # an anonymous non-inherited accessor for __PACKAGE__
+      varclass  => [qw/boo/],     # non-inherited accessor for __PACKAGE__,  aliased with 'our $boo' variable
   ;
   
   use Class::Accessor::Inherited::XS { # optional braces
@@ -102,11 +137,16 @@ Class::Accessor::Inherited::XS - Fast XS inherited accessors
         bar => 'bar_key',
         foo => 'foo_key',
       },
+      class     => ['baz'],
+      varclass  => ['boo'],
   };
   
-  #or in the Class::Accessor::Grouped-like fashion
+  #or in a Class::Accessor::Grouped-like fashion
   use parent 'Class::Accessor::Inherited::XS';
+  
   __PACKAGE__->mk_inherited_accessors('foo', ['bar', 'bar_key']);
+  __PACKAGE__->mk_class_accessors('baz');
+  __PACKAGE__->mk_varclass_accessors('boo');
 
 =head1 DESCRIPTION
 
@@ -119,6 +159,10 @@ Since this module focuses primary on speed, it provides no capability to have yo
 getters/setters logic (like overriding L<get_inherited>/L<set_inherited> in L<Class::Accessor::Grouped>),
 but it gives you an ability to register a single get/set callback for you own accessor types.
 
+It also provides two types of non-inherited accessors - 'class' and 'varclass' with the only difference
+that 'varclass' internal storage is an alias to a package variable of the same name. They always give you
+package value, even when called on an object.
+
 =head1 UTF-8
 
 Starting with the perl 5.16.0, this module provides full support for UTF-8 method names and hash 
